/* $Id: mkvar_test.c,v 1.4 2004/12/26 20:59:45 xsa Exp $ */

/* Public Domain */

/* make variables test */

#include <stdio.h>

#include "../common.h"
#include "../compat/compat.h"
#include "../dynarray.h"

int main(void) {
	char	tmp[256];

	get_make_var("CC", tmp, 256);
	printf("CC => %s\n", tmp);

	get_make_var("CFLAGS", tmp, 256);
	printf("CFLAGS => %s\n", tmp);

	get_make_var("LDFLAGS", tmp, 256);
	printf("LDFLAGS => %s\n", tmp);

	return(0);
}
